@@ -4,10 +4,10 @@ prob_assgn <- 0.5
 design_a <-
   declare_population(N = 100, u = rnorm(N), X = runif(N, 0, 2)) +
   declare_potential_outcomes(Y_Z_0 = u, Y_Z_1 = u + rnorm(N, .5)) +
-  declare_assignment(prob = prob_assgn) + 
-  declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0), label = "ATE") +
-  reveal_outcomes() +
-  declare_estimator(Y ~ Z, estimand = "ATE", label = "est1")
+  declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = prob_assgn)) + 
+  declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0), label = "ATE") +
+  declare_reveal() +
+  declare_estimator(Y ~ Z, inquiry = "ATE", label = "est1")
 design_b <- redesign(design_a, prob_assgn = 0.1)
 set.seed(2000)
 
@@ -24,7 +24,7 @@ test_that("merge_by_estimator working in compare_diagnoses", {
   
   # 1:1 comparison 
   diagnosis_a <- diagnose_design(design_a, sims = 3, bootstrap_sims = 0)
-  design_c <- insert_step(design_a, declare_estimator(Y ~  Z + X, estimand =  "ATE", term = "Z", model = lm_robust, label = "est2"), after = "est1")
+  design_c <- insert_step(design_a, declare_estimator(Y ~  Z + X, inquiry =  "ATE", term = "Z", model = lm_robust, label = "est2"), after = "est1")
   comparison <- compare_diagnoses(design_a, design_c, sims = 3, merge_by_estimator = TRUE)
   n1 <- length(diagnosis_a$diagnosand_names)
   n2 <- nrow(comparison$compared_diagnoses_df)
@@ -52,8 +52,9 @@ test_that("compare_diagnoses errors when it should", {
   designer <- function(N) {
     declare_population(N = N, noise = rnorm(N)) +
       declare_potential_outcomes(Y ~ 0.20 * Z + noise) +
-      declare_assignment() +
-      declare_estimand(ate = mean(Y_Z_1 - Y_Z_0)) +
+      declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = 0.5)) +
+      declare_inquiry(ate = mean(Y_Z_1 - Y_Z_0)) +
+      declare_reveal() + 
       declare_estimator(Y ~ Z)
   }
   
