@@ -1,6 +1,6 @@
 context("environment problems")
 
-test_that("send estimand to estimator works", {
+test_that("send inquiry to estimator works", {
   my_population <- declare_population(N = 50, noise = rnorm(N))
 
   my_potential_outcomes <-
@@ -9,19 +9,19 @@ test_that("send estimand to estimator works", {
       Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2)
     )
 
-  my_assignment <- declare_assignment(m = 25)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 25))
 
-  pate <- declare_estimand(mean(Y_Z_1 - Y_Z_0), label = "pate")
+  pate <- declare_inquiry(mean(Y_Z_1 - Y_Z_0), label = "pate")
 
-  pate_estimator <- declare_estimator(Y ~ Z, estimand = pate, label = "test")
+  pate_estimator <- declare_estimator(Y ~ Z, inquiry = pate, label = "test")
 
-  reveal_outcomes <- reveal_outcomes()
+  declare_reveal <- declare_reveal()
 
   my_design <- my_population +
     my_potential_outcomes +
     pate +
     my_assignment +
-    reveal_outcomes +
+    declare_reveal +
     pate_estimator
 
   rm(list = ls()[-which(ls() %in% "my_design")])
