@@ -4,10 +4,10 @@ context("functions in designers")
 
 test_that("simple designer works", {
   my_designer <- function(N = 100,
-                            my_estimand_func = mean) {
+                            my_inquiry_func = mean) {
     my_pop <- declare_population(N = N, Y = rnorm(N))
-    my_estimand <- declare_estimand(mand = my_estimand_func(Y))
-    my_design <- my_pop + my_estimand
+    my_inquiry <- declare_inquiry(inquiry = my_inquiry_func(Y))
+    my_design <- my_pop + my_inquiry
     my_design
   }
 
@@ -15,21 +15,21 @@ test_that("simple designer works", {
     expand_design(
       designer = my_designer,
       N = c(c(20, 20, 20), c(20, 20, 20), c(20, 20, 20)),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     ), 18)
 
   expect_length(design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     ), 6)
 
   expect_length(design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = list(mean, median)
+      my_inquiry_func = list(mean, median)
     ), 6)
 
 
@@ -37,17 +37,17 @@ test_that("simple designer works", {
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = mean
+      my_inquiry_func = mean
     ), 3)
 })
 
 
 test_that("designer with vector argument works", {
   my_designer <- function(N = c(100, 50),
-                            my_estimand_func = mean) {
+                            my_inquiry_func = mean) {
     my_pop <- declare_population(N = min(N), Y = rnorm(N))
-    my_estimand <- declare_estimand(mand = my_estimand_func(Y))
-    my_design <- my_pop + my_estimand
+    my_inquiry <- declare_inquiry(inquiry = my_inquiry_func(Y))
+    my_design <- my_pop + my_inquiry
     my_design
   }
 
@@ -55,7 +55,7 @@ test_that("designer with vector argument works", {
     expand_design(
       designer = my_designer,
       N = list(c(20, 20, 20), c(20, 20, 20), c(20, 20, 20)),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     ), 6)
 })
 
@@ -65,10 +65,10 @@ test_that("designer with vector argument works", {
 context("functions in designers")
 
 my_designer <- function(N = 100,
-                        my_estimand_func = mean) {
+                        my_inquiry_func = mean) {
   my_pop <- declare_population(N = N, Y = rnorm(N))
-  my_estimand <- declare_estimand(mand = my_estimand_func(Y))
-  my_design <- my_pop + my_estimand
+  my_inquiry <- declare_inquiry(inquiry = my_inquiry_func(Y))
+  my_design <- my_pop + my_inquiry
   my_design
 }
 
@@ -78,39 +78,39 @@ test_that("expand_design works", {
     expand_design(
       designer = my_designer,
       N = c(c(20, 20, 20), c(20, 20, 20), c(20, 20, 20)),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     )
   diag <- diagnose_design(design_list, sims = 5, bootstrap_sims = FALSE)
-  expect_true(all(c("N", "my_estimand_func") %in% names(diag$diagnosands_df)))
+  expect_true(all(c("N", "my_inquiry_func") %in% names(diag$diagnosands_df)))
 
   design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     )
   diag <- diagnose_design(design_list, sims = 5, bootstrap_sims = FALSE)
-  expect_true(all(c("N", "my_estimand_func") %in% names(diag$diagnosands_df)))
+  expect_true(all(c("N", "my_inquiry_func") %in% names(diag$diagnosands_df)))
 
   design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = list(mean, median)
+      my_inquiry_func = list(mean, median)
     )
   diag <- diagnose_design(design_list, sims = 5, bootstrap_sims = FALSE)
-  expect_true(all(c("N", "my_estimand_func") %in% names(diag$diagnosands_df)))
+  expect_true(all(c("N", "my_inquiry_func") %in% names(diag$diagnosands_df)))
 
 
   design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = mean
+      my_inquiry_func = mean
     )
 
   diag <- diagnose_design(design_list, sims = 5, bootstrap_sims = FALSE)
-  expect_true(all(c("N", "my_estimand_func") %in% names(diag$diagnosands_df)))
+  expect_true(all(c("N", "my_inquiry_func") %in% names(diag$diagnosands_df)))
 })
 
 
@@ -118,10 +118,10 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
   my_designer <- function(N, ate) {
     pop <- declare_population(N = N, noise = rnorm(N))
     pos <- declare_potential_outcomes(Y ~ ate * Z + noise)
-    assgn <- declare_assignment(m = N / 2)
-    mand <- declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0))
-    mator <- declare_estimator(Y ~ Z, estimand = mand)
-    pop + pos + assgn + mand + mator
+    assgn <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = N / 2))
+    inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0))
+    estimator <- declare_estimator(Y ~ Z, inquiry = inquiry)
+    pop + pos + assgn + inquiry + estimator
   }
 
   designs <- expand_design(my_designer, N = seq(30, 100, 10), ate = seq(0, .5, length.out = 3))
@@ -145,10 +145,10 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
 
 
   my_designer <- function(N = 100,
-                            my_estimand_func = mean) {
+                            my_inquiry_func = mean) {
     my_pop <- declare_population(N = N, Y = rnorm(N))
-    my_estimand <- declare_estimand(mand = my_estimand_func(Y))
-    my_design <- my_pop + my_estimand
+    my_inquiry <- declare_inquiry(inquiry = my_inquiry_func(Y))
+    my_design <- my_pop + my_inquiry
     my_design
   }
 
@@ -156,7 +156,7 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = c(mean, median)
+      my_inquiry_func = c(mean, median)
     )
 
   expect_equal(sapply(design_list, attr, "parameters"), structure(list(
@@ -165,7 +165,7 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
   ), .Dim = c(
     2L,
     6L
-  ), .Dimnames = list(c("N", "my_estimand_func"), c(
+  ), .Dimnames = list(c("N", "my_inquiry_func"), c(
     "design_1",
     "design_2", "design_3", "design_4", "design_5", "design_6"
   ))))
@@ -174,22 +174,22 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = 10
+      my_inquiry_func = 10
     )
 
   expect_equal(sapply(design_list, attr, "parameters"), structure(list("10", "10", "50", "10", "100", "10"), .Dim = 2:3, .Dimnames = list(
-    c("N", "my_estimand_func"), c("design_1", "design_2", "design_3")
+    c("N", "my_inquiry_func"), c("design_1", "design_2", "design_3")
   )))
 
   design_list <-
     expand_design(
       designer = my_designer,
       N = c(10, 50, 100),
-      my_estimand_func = mean
+      my_inquiry_func = mean
     )
 
   expect_equal(sapply(design_list, attr, "parameters"), structure(list("10", "mean", "50", "mean", "100", "mean"), .Dim = 2:3, .Dimnames = list(
-    c("N", "my_estimand_func"), c("design_1", "design_2", "design_3")
+    c("N", "my_inquiry_func"), c("design_1", "design_2", "design_3")
   )))
 })
 
@@ -197,10 +197,10 @@ test_that("even more kinds of parameters can be sent, vectors and scalars, etc."
 test_that("edge case with expand but one arg works", {
   
   my_designer <- function(N = 100,
-                          my_estimand_func = mean) {
+                          my_inquiry_func = mean) {
     my_pop <- declare_population(N = N, Y = rnorm(N))
-    my_estimand <- declare_estimand(mand = my_estimand_func(Y))
-    my_design <- my_pop + my_estimand
+    my_inquiry <- declare_inquiry(inquiry = my_inquiry_func(Y))
+    my_design <- my_pop + my_inquiry
     my_design
   }
   
@@ -215,13 +215,13 @@ test_that("expand with vector arguments", {
   my_designer <- function(N=10, z = list(1,5,9)) {
     my_pop <- declare_population(top=add_level(N = length(z), z=unlist(z)), 
                                  bottom=add_level(N=z, Y = rnorm(N)))
-    my_estimand <- declare_estimand(mand = max(table(top)))
-    my_design <- my_pop + my_estimand
+    my_inquiry <- declare_inquiry(inquiry = max(table(top)))
+    my_design <- my_pop + my_inquiry
     my_design
   }
   
   expect_equal(
-    draw_estimands(expand_design(my_designer, z=list(2)))$estimand, 2)
+    draw_inquiries(expand_design(my_designer, z=list(2)))$estimand, 2)
   
   
   zx <- list(1:4, 2:10, 9:1, list(4,9,2))
@@ -229,7 +229,7 @@ test_that("expand with vector arguments", {
   dsns <- expand_design(my_designer, z=zx)
   
   expect_equivalent(
-    unlist(sapply(dsns, draw_estimands)[2,]),
+    unlist(sapply(dsns, draw_inquiries)[2,]),
     sapply(zx, function(x)max(unlist(x)))
   )
   
