@@ -1,13 +1,13 @@
 context("Multiple estimators")
 
-test_that("Two estimators, Two estimands (matched)", {
+test_that("Two estimators, Two inquiries (matched)", {
   des <-
     declare_population(sleep) +
-    declare_estimand(
+    declare_inquiry(
       CATE_1_5 = mean(extra[group == 2]) - mean(extra[group == 1]),
       subset = ID %in% 1:5
     ) +
-    declare_estimand(
+    declare_inquiry(
       CATE_6_10 = mean(extra[group == 2]) - mean(extra[group == 1]),
       subset = ID %in% 6:10
     ) +
@@ -16,7 +16,7 @@ test_that("Two estimators, Two estimands (matched)", {
       extra ~ group,
       subset = ID %in% 1:5,
       model = difference_in_means,
-      estimand = "CATE_1_5",
+      inquiry = "CATE_1_5",
       label = "DIM_1_5",
       term = group2
     ) +
@@ -24,7 +24,7 @@ test_that("Two estimators, Two estimands (matched)", {
       extra ~ group,
       subset = ID %in% 6:10,
       model = difference_in_means,
-      estimand = "CATE_6_10",
+      inquiry = "CATE_6_10",
       label = "DIM_6_10",
       term = group2
     )
@@ -34,20 +34,20 @@ test_that("Two estimators, Two estimands (matched)", {
 })
 
 
-test_that("Two estimators, Two estimands (crossed)", {
+test_that("Two estimators, Two inquiries (crossed)", {
   des <-
     declare_population(sleep) +
     # Make a noisier outcome
     declare_potential_outcomes(extra1 ~ extra + 2 * (Z == 1) + rnorm(length(extra))) +
 
-    declare_estimand(ATE = mean(extra1_Z_1) - mean(extra1_Z_0)) +
-    declare_estimand(ATT = mean(extra1_Z_1) - mean(extra1_Z_0), subset = group == 2) +
+    declare_inquiry(ATE = mean(extra1_Z_1) - mean(extra1_Z_0)) +
+    declare_inquiry(ATT = mean(extra1_Z_1) - mean(extra1_Z_0), subset = group == 2) +
 
-    declare_assignment() +
-    reveal_outcomes(outcome_variables = extra1, assignment_variables = Z) +
+    declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = 0.5)) +
+    declare_reveal(outcome_variables = extra1, assignment_variables = Z) +
 
-    declare_estimator(extra1 ~ Z, model = difference_in_means, estimand = c("ATE", "ATT"), label = "DIM") +
-    declare_estimator(extra1 ~ Z + group, model = lm_robust, clusters = ID, estimand = c("ATE", "ATT"), label = "OLS + control")
+    declare_estimator(extra1 ~ Z, model = difference_in_means, inquiry = c("ATE", "ATT"), label = "DIM") +
+    declare_estimator(extra1 ~ Z + group, model = lm_robust, clusters = ID, inquiry = c("ATE", "ATT"), label = "OLS + control")
 
   diag <- diagnose_design(des, sims = 5, bootstrap_sims = FALSE)
   expect_equal(nrow(diag$diagnosands), 4)
