@@ -13,14 +13,14 @@ test_that("multiple potential outcomes", {
     formula = R ~ rbinom(n = N, size = 1, prob = pnorm(Y_Z_0))
   )
 
-  my_assignment <- declare_assignment(m = 25)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 25))
 
   my_design <- my_population +
     my_potential_outcomes_Y +
     my_potential_outcomes_attrition +
     my_assignment +
-    reveal_outcomes(outcome_variable = "R", assignment_variable = "Z") +
-    reveal_outcomes(outcome_variable = "Y", assignment_variable = "Z")
+    declare_reveal(outcome_variable = "R", assignment_variable = "Z") +
+    declare_reveal(outcome_variable = "Y", assignment_variable = "Z")
 
   expect_true(all(
     c("R", "Y") %in% colnames(draw_data(my_design))
