@@ -7,20 +7,20 @@ my_population <- declare_population(N = N, noise = rnorm(N))
 my_potential_outcomes <-
   declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2))
 
-my_sampling <- declare_sampling(n = 250)
+my_sampling <- declare_sampling(legacy = FALSE, S = complete_rs(N, n = 250))
 
-my_assignment <- declare_assignment(m = 25)
+my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 25))
 
-my_estimand <- declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0))
+my_inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0))
 
-my_estimator <- declare_estimator(Y ~ Z, estimand = my_estimand)
+my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
 
-my_reveal <- reveal_outcomes()
+my_reveal <- declare_reveal()
 
 design <- my_population +
   my_potential_outcomes +
   my_sampling +
-  my_estimand +
+  my_inquiry +
   declare_step(dplyr::mutate, q = 5) +
   my_assignment +
   my_reveal +
@@ -29,10 +29,10 @@ design <- my_population +
 test_that("reshape works", {
   dx <- diagnose_design(design, sims = 10, bootstrap_sims = 5)
   reshape_diagnosis(dx)
-  expect_error(reshape_diagnosis(dx, select = "mean_estimand"),
+  expect_error(reshape_diagnosis(dx, select = "mean_inquiry"),
     regexp = "select argument must only include elements from"
   )
-  reshape_diagnosis(dx, select = "Mean Estimand")
+  reshape_diagnosis(dx, select = "Mean Inquiry")
 })
 
 
@@ -44,11 +44,11 @@ test_that("capitalization of parameter names are retained", {
         Y_Z_0 = noise,
         Y_Z_1 = noise + rnorm(N, mean = 2, sd = 2)
       )
-    my_smp <- declare_sampling(n = n)
-    my_asgn <- declare_assignment(m = floor(n / 2))
-    my_mand <- declare_estimand(mean(Y_Z_1) - mean(Y_Z_0))
-    my_estimator <- declare_estimator(Y ~ Z, estimand = my_mand)
-    my_design <- my_pop + my_pos + my_mand + my_smp + my_asgn + reveal_outcomes() + my_estimator
+    my_smp <- declare_sampling(legacy = FALSE, S = complete_rs(N, n = n))
+    my_asgn <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = floor(n / 2)))
+    my_inquiry <- declare_inquiry(mean(Y_Z_1) - mean(Y_Z_0))
+    my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
+    my_design <- my_pop + my_pos + my_inquiry + my_smp + my_asgn + declare_reveal() + my_estimator
     my_design
   }
 
@@ -76,7 +76,7 @@ test_that("capitalization of parameter names are retained", {
 test_that("select", {
   dx <- diagnose_design(design, sims = 10, bootstrap_sims = 5)
   reshape <- reshape_diagnosis(dx, select = "Bias")
-  expect_equal(colnames(reshape), c("Design Label", "Estimand Label", "Estimator Label", "Term", "N Sims", "Bias"))
+  expect_equal(colnames(reshape), c("Design Label", "Inquiry Label", "Estimator Label", "Term", "N Sims", "Bias"))
 })
 
 
@@ -89,7 +89,7 @@ test_that("designs with factors in diagnosands_df do not produce warnings", {
   design <- design <- my_population +
     declare_estimator(handler = label_estimator(my_estimator), label = "my_label")
 
-  diagnose_design(design, sims = 2, diagnosands = declare_diagnosands(first = first(estimate)))
+  diagnose_design(design, sims = 2, diagnosands = declare_diagnosands(first = estimate[1]))
   
   my_estimator <- function(data) {
     data.frame(estimate = c("answer1", "answer2"), estimator_label = "my_label", stringsAsFactors = TRUE)
@@ -98,6 +98,29 @@ test_that("designs with factors in diagnosands_df do not produce warnings", {
   design <- design <- my_population +
     declare_estimator(handler = my_estimator)
   
-  expect_silent(reshape_diagnosis(diagnose_design(design, sims = 2, diagnosands = declare_diagnosands(first = first(estimate)))))
+  expect_silent(reshape_diagnosis(diagnose_design(design, sims = 31, diagnosands = declare_diagnosands(first = estimate[1]))))
+  
+})
+
+test_that("groups with factors", {
+  
+  design <- 
+    declare_population(N = 100, u = rnorm(N)) + 
+    declare_potential_outcomes(Y_Z_0 = 0, Y_Z_1 = ifelse(rbinom(N, 1, prob = 0.5), 0.1, -0.1) + u) +
+    declare_assignment() + 
+    declare_inquiry(ATE_positive = mean(Y_Z_1 - Y_Z_0) > 0) + 
+    declare_reveal() + 
+    declare_estimator(Y ~ Z, inquiry = "ATE_positive")
+  
+  diagnosis <- diagnose_design(design, 
+                               make_groups = vars(significant = ifelse(p.value > 0.5, NA, p.value <= 0.05)),
+                               sims = 100
+  )
+  
+  diagnosis <- diagnose_design(design, 
+                               make_groups = vars(significant = factor(ifelse(p.value > 0.5, NA, p.value <= 0.05))),
+                               sims = 100
+  )
+  
   
 })
