@@ -7,9 +7,9 @@ context("Reveal Outcomes")
 test_that("Reveal Outcomes", {
   my_population <- declare_population(N = 1000, u = rnorm(N))
 
-  my_sampling <- declare_sampling(n = 100)
+  my_sampling <- declare_sampling(legacy = FALSE, S = complete_rs(N, n = 100))
 
-  my_assignment <- declare_assignment(m = 50)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 50))
 
   my_potential_outcomes <-
     declare_potential_outcomes(
@@ -17,13 +17,13 @@ test_that("Reveal Outcomes", {
       Y_Z_1 = u + .25
     )
 
-  my_estimand <- declare_estimand(ATE = mean(Y_Z_1 - Y_Z_0))
+  my_inquiry <- declare_inquiry(ATE = mean(Y_Z_1 - Y_Z_0))
 
-  my_estimator <- declare_estimator(Y ~ Z, estimand = my_estimand)
+  my_estimator <- declare_estimator(Y ~ Z, inquiry = my_inquiry)
 
-  my_reveal <- reveal_outcomes()
+  my_reveal <- declare_reveal()
 
-  my_design <- my_population + my_potential_outcomes + my_estimand + my_sampling + my_assignment + my_reveal + my_estimator
+  my_design <- my_population + my_potential_outcomes + my_inquiry + my_sampling + my_assignment + my_reveal + my_estimator
 
   dat <- draw_data(my_design)
 
@@ -39,20 +39,20 @@ test_that("Reveal Outcomes NSE for assignment / outcome variables ", {
 
   my_potential_outcomes <- declare_potential_outcomes(Y_Z_0 = noise, Y_Z_1 = noise + 1)
 
-  my_assignment <- declare_assignment(prob = 1)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = 1))
 
-  design <- my_population + my_potential_outcomes + my_assignment + reveal_outcomes()
+  design <- my_population + my_potential_outcomes + my_assignment + declare_reveal()
 
   df1 <- draw_data(design)
 
 
   design <- my_population + my_potential_outcomes + my_assignment +
-    reveal_outcomes(assignment_variables = Z, outcome_variables = Y)
+    declare_reveal(assignment_variables = Z, outcome_variables = Y)
 
   df2 <- draw_data(design)
 
   design <- my_population + my_potential_outcomes + my_assignment +
-    reveal_outcomes(assignment_variable = "Z", outcome_variable = "Y")
+    declare_reveal(assignment_variable = "Z", outcome_variable = "Y")
 
   df3 <- draw_data(design)
 
@@ -66,31 +66,31 @@ test_that("reveal multiple outcomes works", {
   my_population <- declare_population(N = N, noise = 1:N)
   my_potential_outcomes1 <- declare_potential_outcomes(formula = Y1 ~ Z * .25, conditions = c(0, 1))
   my_potential_outcomes2 <- declare_potential_outcomes(formula = Y2 ~ Z * .5 + 3, conditions = c(0, 1))
-  my_assignment <- declare_assignment(prob = 1)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, prob = 1))
 
   design <- my_population + my_potential_outcomes1 + my_potential_outcomes2 + my_assignment +
-    reveal_outcomes(outcome_variables = c(Y1, Y2))
+    declare_reveal(outcome_variables = c(Y1, Y2))
   df1 <- draw_data(design)
 
   design <- my_population + my_potential_outcomes1 + my_potential_outcomes2 + my_assignment +
-    reveal_outcomes(outcome_variables = c("Y1", "Y2"))
+    declare_reveal(outcome_variables = c("Y1", "Y2"))
   df2 <- draw_data(design)
 
   expect_identical(df1, df2)
 })
 
-test_that("reveal_outcomes custom handler works", {
+test_that("declare_reveal custom handler works", {
   N <- 25
 
   my_population <- declare_population(N = N, noise = rnorm(N))
-  my_assignment <- declare_assignment(m = 10)
+  my_assignment <- declare_assignment(legacy = FALSE, Z = complete_ra(N, m = 10))
 
   my_outcome_function <- function(data) {
     data$Y <- rnorm(nrow(data))
     return(data)
   }
 
-  design <- my_population + my_assignment + reveal_outcomes(handler = my_outcome_function)
+  design <- my_population + my_assignment + declare_reveal(handler = my_outcome_function)
   df <- draw_data(design)
 
   expect_true("Y" %in% colnames(df))
@@ -98,7 +98,7 @@ test_that("reveal_outcomes custom handler works", {
 
 test_that("missing PO stops", {
   expect_error(
-    reveal_outcomes(outcome_variables = foo, assignment_variables = extra)(sleep)
+    declare_reveal(outcome_variables = foo, assignment_variables = extra)(sleep)
   )
 })
 
@@ -106,7 +106,7 @@ test_that("Not all Potential outcome columns present", {
   df <- data.frame(Z = sample(1:3, 100, replace = TRUE), Y_Z_0 = 1:100, Y_Z_1 = 1:100)
 
   expect_error(
-    reveal_outcomes()(df),
+    declare_reveal()(df),
     "Y_Z_3"
   )
 })
@@ -132,14 +132,14 @@ test_that("Single outcome, multiple assn", {
 
 
   # Factorial assignments
-  assign_A <- declare_assignment(
-    blocks = blocks, assignment_variable = A
+  assign_A <- declare_assignment(legacy = FALSE, 
+    A = block_ra(blocks = blocks)
   )
-  assign_B <- declare_assignment(
-    blocks = A + 10 * as.numeric(blocks), assignment_variable = B
+  assign_B <- declare_assignment(legacy = FALSE, 
+    B = block_ra(blocks = A + 10 * as.numeric(blocks))
   )
 
-  design <- population + potential_outcomes + assign_A + assign_B + reveal_outcomes(outcome_variables = Y, assignment_variables = c(A, B))
+  design <- population + potential_outcomes + assign_A + assign_B + declare_reveal(outcome_variables = Y, assignment_variables = c(A, B))
 
   dd <- draw_data(design)
 
